permission_handler_plus_html

技术支持邮箱(1539841933@qq.com)。

pub package Build status style: flutter lints

The official web implementation of the permission_handler_plus plugin by Baseflow.

Usage

This is the officially endorsed web implementation of the permission_handler_plus plugin. This means it will automatically be added to your dependencies when you depend on permission_handler_plus in your applications pubspec.yaml.

More detailed instructions on using the API can be found in the README.md of the permission_handler_plus package.

Issues

Please file any issues, bugs, or feature requests as an issue on our GitHub page. Commercial support is available, you can contact us at hello@baseflow.com.

Want to contribute

If you would like to contribute to the plugin (e.g. by improving the documentation, solving a bug, or adding a cool new feature), please carefully review our contribution guide and send us your pull request.

Author

This permission_handler_plus plugin for Flutter is developed by Baseflow.